==> foundation-ui-components-1.28.0-cx130-1216.1.tgz: package/src/common/card/NsMediumCard.tsx <==
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';

import { NsTypography } from '../';
import { BynderMedia } from '../image/BynderMedia';
import CardButton from './CardButton';
import { NsCardButton } from './types';
import { BynderImageDataType } from '../image/types';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    backgroundImageDetail: BynderImageDataType;
    button?: NsCardButton;
    className?: string;
    fluid?: boolean;
    showArrowWithButtonText?: boolean;
};
const textVariantButton = {
    padding: '0 0 4px',
    gap: '7px',
    span: {
        margin: 0,
    },
    '> div': {
        margin: 0,
    },
    '.MuiButton-endIcon': {
        svg: {
            g: {
                strokeWidth: 2,
            },
        },
    },
};
const buttonVariantStyle = (variant: string) => (variant === 'text' ? { a: textVariantButton } : {});
const CardContainer = styled(Box)<{ fluid: boolean; variant: string }>(({ fluid, variant }) => {
    const textVariantCssModification = buttonVariantStyle(variant);

    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: fluid ? '100%' : '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: fluid ? '100%' : '300px',
            flexDirection: 'column',
            flexGrow: 1,
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: 'auto',
            ...textVariantCssModification,
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageDetail,
    button,
    className,
    fluid,
    showArrowWithButtonText = false,
}: NsMediumCardProps) {
    return (
        <CardContainer
            className={className}
            role="medium-card"
            component="div"
            data-testid="medium-card"
            fluid={fluid || false}
            variant={button?.buttonVariant ?? ''}
        >
            <BynderMedia className="image" imageDetail={backgroundImageDetail} />
            <div className="content">
                <NsTypography variant="h5" color="primary" className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className="subtitle mt-3 mb-5">{subtitle}</article>
                {button ? <CardButton {...button} showArrowWithText={showArrowWithButtonText} /> : null}
            </div>
        </CardContainer>
    );
}

==> foundation-ui-components-1.29.1-cx130-1299.2.tgz: package/src/common/card/NsMediumCard.tsx <==
import { NsCardButton } from './types';
import Box from '@mui/material/Box';
import { styled } from '@nuskin/foundation-theme';
import { ReactNode } from 'react';

import { NsImage, NsTypography } from '../';
import CardButton from './CardButton';

type NsMediumCardProps = {
    title: string;
    titleFontWeight?: 'bold' | 'normal' | 'light';
    subtitle: string;
    backgroundImageUrl: string;
    backgroundImageAlt: string;
    button?: NsCardButton;
    className?: string;
    fluid?: boolean;
    showArrowWithButtonText?: boolean;
};
const textVariantButton = {
    padding: '0 0 4px',
    gap: '7px',
    span: {
        margin: 0,
    },
    '> div': {
        margin: 0,
    },
    '.MuiButton-endIcon': {
        svg: {
            g: {
                strokeWidth: 2,
            },
        },
    },
};
const buttonVariantStyle = (variant: string) => (variant === 'text' ? { a: textVariantButton } : {});
const CardContainer = styled(Box)<{ fluid: boolean; variant: string }>(({ fluid, variant }) => {
    const textVariantCssModification = buttonVariantStyle(variant);

    return {
        display: 'flex',
        flexDirection: 'column',
        position: 'relative',
        '.image': {
            width: fluid ? '100%' : '300px',
            height: '300px',
            objectFit: 'cover',
        },
        '.content': {
            display: 'flex',
            width: fluid ? '100%' : '300px',
            flexDirection: 'column',
            flexGrow: 1,
        },
        '.subtitle': {
            fontSize: '16px',
            fontWeight: '400',
        },
        '.title': {
            fontSize: '20px',
            marginTop: '10px',
        },
        '.cta': {
            marginTop: 'auto',
            ...textVariantCssModification,
        },
    };
});

export default function NsMediumCard({
    title,
    titleFontWeight,
    subtitle,
    backgroundImageUrl,
    backgroundImageAlt,
    button,
    className,
    fluid,
    showArrowWithButtonText = false,
}: NsMediumCardProps): ReactNode {
    return (
        <CardContainer
            className={className}
            role="medium-card"
            component="div"
            data-testid="medium-card"
            fluid={fluid || false}
            variant={button?.buttonVariant ?? ''}
        >
            <NsImage alt={backgroundImageAlt} src={backgroundImageUrl} className="image" />
            <div className="content">
                <NsTypography variant="h5" color="primary" className="title" weight={titleFontWeight}>
                    {title}
                </NsTypography>
                <article className="subtitle mt-3 mb-5">{subtitle}</article>
                {button ? <CardButton {...button} showArrowWithText={showArrowWithButtonText} /> : null}
            </div>
        </CardContainer>
    );
}
